@@ -45,7 +45,7 @@ CONFIG_FILE_NAME = ".pyradrc"
 DEFAULT_CONFIG = '''# v0.1 keep this line!
 [
     ("''' + CENTER_ICON + '''", None), # the center item: (icon, action); action == None means "quit"
-    ("konsole","konsole"), ("kontact","kontact"), ("konqueror","konqueror"), ("wesnoth-icon","wesnoth"), # normal items
+    ("terminal","konsole"), ("kontact","kontact"), ("konqueror","konqueror"), ("wesnoth-icon","wesnoth"), # normal items
     ("krita","""[("''' + CENTER_ICON + '''", None), ("amarok", "amarok"), ("gimp","gimp")]""") # a folder with the center icon and only one real item
 ]
 '''
@@ -53,6 +53,9 @@ DEFAULT_CONFIG = '''# v0.1 keep this line!
 #: The keys for accessing pyrad element via the keyboard
 SELECTION_KEYS_ORDERED = "0123456789abcdefghijklmnopqrstuvwxyz"
 
+#: The maximum length of the shown tooltips (avoids missing tooltips when the tip is too long).
+MAX_TOOL_TIP_LENGTH = 100
+
 ### Window ###
 
 class ItemEditWidget(QWidget):
@@ -342,12 +345,17 @@ class Rad(QWidget):
             if SELECTION_KEYS_ORDERED[len(circle):]: 
                 key = SELECTION_KEYS_ORDERED[len(circle)]
                 if action is not None and action.startswith("["):
-                    toolTip =  key + " - " + ", ".join([act for ico,act in eval(action) if act])
+                    toolTip =  key + " - " + "(" + ", ".join([str(act) for ico,act in eval(action) if act]) + ")"
                 else: 
                     toolTip =  key + " - " + str(action)
             else:
                 toolTip = str(action)
-            label.setToolTip(toolTip)
+            # toolTip = toolTip.replace('"', "")
+            # print(toolTip)
+            if toolTip[MAX_TOOL_TIP_LENGTH:]: 
+                label.setToolTip(toolTip[:MAX_TOOL_TIP_LENGTH]+"...")
+            else:
+                label.setToolTip(toolTip)
             circle.append(label)
 
         return circle
